# aioaprs

> Async Python3 libraray implementing an APRS-IS client

This library aims to implement a complete APRS-IS client based on the modern async pattern in Python 3.

It's heavily based on `aprslib`, available on
[https://github.com/rossengeorgiev/aprs-python](https://github.com/rossengeorgiev/aprs-python).

## Usage

TODO
